<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>AddProfileWindow</name>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="27"/>
        <source>Please enter a profile name.</source>
        <translation>Veuillez entrer un nom de profil.</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="28"/>
        <source>A profile with this name already exists.</source>
        <translation>Un profil avec ce nom existe déjà.</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="24"/>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="25"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>AddRepoWindow</name>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="80"/>
        <source>Repository Path:</source>
        <translation>Chemin d&apos;accès du dépôt :</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="83"/>
        <source>Choose Location of Borg Repository</source>
        <translation>Choisissez l&apos;emplacement du dépôt Borg</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="112"/>
        <source>Repository URL:</source>
        <translation>URL du dépôt :</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="138"/>
        <source>Unable to add your repository.</source>
        <translation>Impossible d&apos;ajouter le dépôt.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="165"/>
        <source>Please enter a valid repo URL or select a local path.</source>
        <translation>Saisissez un chemin d&apos;accès URL valide ou sélectionnez un répertoire local</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="169"/>
        <source>This repo has already been added.</source>
        <translation>Ce dépôt a déjà été ajouté.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="105"/>
        <source>Show my passwords</source>
        <translation>Montrer mes mots de passe</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="90"/>
        <source>Autofilled password from password manager.</source>
        <translation>Mot de passe auto-rempli depuis le gestionnaire de mots de passe.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="102"/>
        <source>Hide my passwords</source>
        <translation>Cacher mes mots de passe</translation>
    </message>
</context>
<context>
    <name>AddRepository</name>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="60"/>
        <source>Initialize New Backup Repository</source>
        <translation>Initialiser un nouveau dépôt de sauvegarde</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="67"/>
        <source>Repository URL:</source>
        <translation>URL du dépôt :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="82"/>
        <source>csvis8xq@csvis8xq.repo.borgbase.com:repo</source>
        <translation>csvis8xq@csvis8xq.repo.borgbase.com:repo</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="89"/>
        <source>Choose a local path as repository.</source>
        <translation>Choisir un emplacement local comme dépôt.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="103"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="201"/>
        <source>Encryption:</source>
        <translation>Chiffrement :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="179"/>
        <source>SSH Key:</source>
        <translation>Clé SSH :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="193"/>
        <source>Automatically choose SSH Key (default)</source>
        <translation>Choisir automatiquement une clef SSH (par défaut)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="247"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="254"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="33"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="158"/>
        <source>Advanced</source>
        <translation>Avancé</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="218"/>
        <source>Extra Borg Arguments:</source>
        <translation>Arguments Supplémentaires Pour Borg :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="116"/>
        <source>Borg passphrase:</source>
        <translation>Phrase de passe pour Borg:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="143"/>
        <source>Confirm passphrase:</source>
        <translation>Confirmer la phrase de passe:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="150"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
</context>
<context>
    <name>ArchiveTab</name>
    <message>
        <location filename="../../views/archive_tab.py" line="144"/>
        <source>Archives for %s</source>
        <translation>Archives de %s</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="177"/>
        <source>Archives</source>
        <translation>Archives</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="194"/>
        <source>Preview: %s</source>
        <translation>Aperçu : %s</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="198"/>
        <source>Error in archive name template.</source>
        <translation>Erreur du gabarit de nom d&apos;archive. </translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="242"/>
        <source>Pruning finished.</source>
        <translation>Élagage terminé.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="261"/>
        <source>Refreshed archives.</source>
        <translation>Archives mises à jour. </translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="315"/>
        <source>Choose Mount Point</source>
        <translation>Choisir le point de montage</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="321"/>
        <source>Mounted successfully.</source>
        <translation>Montage réussi.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="348"/>
        <source>Mount point not active.</source>
        <translation>Point de montage inactif.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="355"/>
        <source>Un-mounted successfully.</source>
        <translation>Démonté avec succès. </translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="392"/>
        <source>Select an archive to restore first.</source>
        <translation>Sélectionner une archive à restaurer en premier.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="412"/>
        <source>Choose Extraction Point</source>
        <translation>Choisissez le point d&apos;extraction</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="475"/>
        <source>Archive deleted.</source>
        <translation>Archive supprimée.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="460"/>
        <source>Confirm deletion</source>
        <translation>Confirmer la suppression</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="560"/>
        <source>No archive selected</source>
        <translation>Aucune archive sélectionnée</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="460"/>
        <source>Are you sure you want to delete the archive?</source>
        <translation>Êtes-vous certain de vouloir supprimer l&apos;archive?</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="448"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="449"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="98"/>
        <source>Action cancelled.</source>
        <translation>Action annulée.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="361"/>
        <source>Unmounting failed. Make sure no programs are using {}</source>
        <translation>Échec  du démontage. Assurez-vous qu&apos;aucun programme n&apos;utilise {}</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="117"/>
        <source>Select an archive first.</source>
        <translation>Sélectionnez d&apos;abord une archive.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="533"/>
        <source>Change name</source>
        <translation>Changer le nom</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="533"/>
        <source>New archive name:</source>
        <translation>Nouveau nom d&apos;archive:</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="543"/>
        <source>Archive name cannot be blank.</source>
        <translation>Le nom de l&apos;archive ne peut pas être vide.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="548"/>
        <source>An archive with this name already exists.</source>
        <translation>Une archive du même nom existe déjà.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="564"/>
        <source>Archive renamed.</source>
        <translation>Archive renommée.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="278"/>
        <source>Refreshed archive.</source>
        <translation>Archives mises à jour.</translation>
    </message>
</context>
<context>
    <name>BorgBreakThread</name>
    <message>
        <location filename="../../borg/break_lock.py" line="8"/>
        <source>Breaking repository lock...</source>
        <translation>Cassage du verrou du dépôt... </translation>
    </message>
    <message>
        <location filename="../../borg/break_lock.py" line="12"/>
        <source>Repository lock broken. Please redo your last action.</source>
        <translation>Verrou du dépôt cassé. Veuillez répéter votre dernière action.</translation>
    </message>
</context>
<context>
    <name>BorgCheckThread</name>
    <message>
        <location filename="../../borg/check.py" line="8"/>
        <source>Starting consistency check...</source>
        <translation>Début du contrôle d&apos;intégrité…</translation>
    </message>
    <message>
        <location filename="../../borg/check.py" line="13"/>
        <source>Check completed.</source>
        <translation>Vérification complétée.</translation>
    </message>
</context>
<context>
    <name>BorgCreateThread</name>
    <message>
        <location filename="../../borg/create.py" line="38"/>
        <source>Backup finished.</source>
        <translation>Sauvegarde terminée.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="45"/>
        <source>Backup started.</source>
        <translation>Sauvegarde débutée. </translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="36"/>
        <source>Backup finished with warnings. See logs for details.</source>
        <translation>La sauvegarde s&apos;est terminé avec des avertissements. Consultez les logs pour plus de détails.</translation>
    </message>
</context>
<context>
    <name>BorgDeleteThread</name>
    <message>
        <location filename="../../borg/delete.py" line="8"/>
        <source>Deleting archive...</source>
        <translation>Suppression de l&apos;archive…</translation>
    </message>
    <message>
        <location filename="../../borg/delete.py" line="13"/>
        <source>Archive deleted.</source>
        <translation>Archive supprimée.</translation>
    </message>
</context>
<context>
    <name>BorgDiffThread</name>
    <message>
        <location filename="../../borg/diff.py" line="9"/>
        <source>Requesting differences between archives...</source>
        <translation>Récupère des différences entre les archives…</translation>
    </message>
    <message>
        <location filename="../../borg/diff.py" line="13"/>
        <source>Obtained differences between archives.</source>
        <translation>Différences entre les archives récupérées.</translation>
    </message>
</context>
<context>
    <name>BorgExtractThread</name>
    <message>
        <location filename="../../borg/extract.py" line="8"/>
        <source>Downloading files from archive...</source>
        <translation>Téléchargement des fichiers depuis l&apos;archive…</translation>
    </message>
    <message>
        <location filename="../../borg/extract.py" line="13"/>
        <source>Restored files from archive.</source>
        <translation>Fichiers restaurés depuis l&apos;archive.</translation>
    </message>
</context>
<context>
    <name>BorgInfoArchiveThread</name>
    <message>
        <location filename="../../borg/info_archive.py" line="9"/>
        <source>Refreshing archive...</source>
        <translation>Rafraîchissement des archives…</translation>
    </message>
    <message>
        <location filename="../../borg/info_archive.py" line="14"/>
        <source>Refreshing archive done.</source>
        <translation>Rafraîchissement des archives terminé.</translation>
    </message>
</context>
<context>
    <name>BorgInfoRepoThread</name>
    <message>
        <location filename="../../borg/info_repo.py" line="9"/>
        <source>Validating existing repo...</source>
        <translation>Validation du dépôt existant...</translation>
    </message>
</context>
<context>
    <name>BorgInitThread</name>
    <message>
        <location filename="../../borg/init.py" line="8"/>
        <source>Setting up new repo...</source>
        <translation>Configurer un nouveau dépôt...</translation>
    </message>
</context>
<context>
    <name>BorgListArchiveThread</name>
    <message>
        <location filename="../../borg/list_archive.py" line="8"/>
        <source>Getting archive content...</source>
        <translation>Obtention du contenu de l&apos;archive…</translation>
    </message>
    <message>
        <location filename="../../borg/list_archive.py" line="12"/>
        <source>Done getting archive content.</source>
        <translation>Contenu de l&apos;archive obtenu. </translation>
    </message>
</context>
<context>
    <name>BorgListRepoThread</name>
    <message>
        <location filename="../../borg/list_repo.py" line="10"/>
        <source>Refreshing archives...</source>
        <translation>Rafraîchissement des archives…</translation>
    </message>
    <message>
        <location filename="../../borg/list_repo.py" line="15"/>
        <source>Refreshing archives done.</source>
        <translation>Rafraîchissement des archives terminé.</translation>
    </message>
</context>
<context>
    <name>BorgMountThread</name>
    <message>
        <location filename="../../borg/mount.py" line="9"/>
        <source>Mounting archive into folder...</source>
        <translation>Montage de l&apos;archive dans un répertoire...</translation>
    </message>
</context>
<context>
    <name>BorgPruneThread</name>
    <message>
        <location filename="../../borg/prune.py" line="9"/>
        <source>Pruning old archives...</source>
        <translation>Élagage des anciennes archives...</translation>
    </message>
    <message>
        <location filename="../../borg/prune.py" line="14"/>
        <source>Pruning done.</source>
        <translation>Élagage terminé. </translation>
    </message>
</context>
<context>
    <name>BorgThread</name>
    <message>
        <location filename="../../borg/borg_thread.py" line="297"/>
        <source>Task started</source>
        <translation>Tâche débutée</translation>
    </message>
    <message>
        <location filename="../../borg/borg_thread.py" line="54"/>
        <source>Files</source>
        <translation>Fichiers</translation>
    </message>
    <message>
        <location filename="../../borg/borg_thread.py" line="55"/>
        <source>Original</source>
        <translation>Original</translation>
    </message>
    <message>
        <location filename="../../borg/borg_thread.py" line="56"/>
        <source>Deduplicated</source>
        <translation>Dédupliqué</translation>
    </message>
    <message>
        <location filename="../../borg/borg_thread.py" line="57"/>
        <source>Compressed</source>
        <translation>Compressé</translation>
    </message>
</context>
<context>
    <name>BorgUmountThread</name>
    <message>
        <location filename="../../borg/umount.py" line="10"/>
        <source>Unmounting archive...</source>
        <translation>Démontage de l&apos;archive</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="25"/>
        <source>Archive:</source>
        <translation>Archive :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="38"/>
        <source>nyx2.local-2018-11-16T09:49:58 from November 16, 2018</source>
        <translation>nyx2.local-2018-11-16T09:49:58 from November 16, 2018</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="63"/>
        <source>Note: If you select a top-level folder and deselect its children, they will still be restored.</source>
        <translation>Note : Si vous sélectionner un dossier sans sélectionner les sous-dossiers, ceux-ci seront quand même restaurés. </translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="88"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="95"/>
        <source>Extract</source>
        <translation>Extraire</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="35"/>
        <source>Add Backup Profile</source>
        <translation>Ajouter un profil de sauvegarde</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Backup profiles allow for granular backups from different sources to different destinations. You could e.g. back up essential documents to a remote repository via Wifi, while doing a full backup onto a local storage device.&lt;/p&gt;&lt;p&gt;Repositories and SSH keys are shared between profiles. Source folders, active destination repo, allowed networks, pruning, validation and scheduling are per-profile.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Les profils de sauvegarde permettent des sauvegardes granulaires depuis différentes sources vers des destinations différentes. Vous pouvez, par exemple, sauvegarder des documents essentiels vers un dépôt distant via Wifi et réaliser une sauvegarde complète sur un appareil de stockage local. &lt;/p&gt;&lt;p&gt;Les dépôts et clés SSH sont partagés entre les profils. Les dossiers sources, dépôts de destination actifs, réseaux autorisés, paramètres d&apos;élagage et de validation ainsi que les horaires de sauvegarde sont spécifiques au profil. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="84"/>
        <source>Profile Name</source>
        <translation>Nom du profil</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="43"/>
        <source>Generate SSH Key</source>
        <translation>Générer une clé SSH</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="55"/>
        <source>Key Format:</source>
        <translation>Format de clé :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="72"/>
        <source>Key Length:</source>
        <translation>Longueur de la clé :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="94"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;2048 or 4096 for RSA, 384 or 521 for ECDSA. Fixed for Ed25519. &lt;a href=&quot;https://stribika.github.io/2015/01/04/secure-secure-shell.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;More&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;2048 ou 4096 pour RSA, 384 ou 521 pour ECDSA. Pré-déterminé pour ED25519.&lt;a href=&quot;https://stribika.github.io/2015/01/04/secure-secure-shell.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;plus d&apos;information&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="107"/>
        <source>Output File:</source>
        <translation>Fichier se sortie :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="119"/>
        <source>Don&apos;t change this if you want SSH to automatically find the key.</source>
        <translation>Ne changez pas ceci si vous voulez que SSH trouve automatiquement la clef.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="128"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="141"/>
        <source>Generate and copy to Clipboard</source>
        <translation>Générer et copier dans le presse-papier</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="25"/>
        <source>Select two archives</source>
        <translation>Sélectionnez deux archives</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="60"/>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="65"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="70"/>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="75"/>
        <source>Mount Point</source>
        <translation>Point de montage</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="80"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="113"/>
        <source>Diff</source>
        <translation>Différence</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="25"/>
        <source>Difference between</source>
        <translation>Différence entre</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="38"/>
        <source>nyx2.local-2018-11-16T09:49:58 </source>
        <translation>nyx2.local-2018-11-16T09:49:58 </translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="45"/>
        <source>and</source>
        <translation>et</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="58"/>
        <source>nyx2.local-2018-10-16T09:49:58 </source>
        <translation>nyx2.local-2018-10-16T09:49:58 </translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="101"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../assets/UI/exportwindow.ui" line="23"/>
        <source>If set, sharing this file with others will disclose your borg passphrase. Use with caution!</source>
        <translation>Si cette option est activée, le partage de ce fichier avec d&apos;autres personnes entraînera la divulgation de votre mot de passe borg. A utiliser avec précaution !</translation>
    </message>
    <message>
        <location filename="../../assets/UI/exportwindow.ui" line="26"/>
        <source>Include borg passphrase in export</source>
        <translation>Inclure le mot de passe borg dans le fichier d&apos;export</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="25"/>
        <source>Borg passphrase:</source>
        <translation>Mot de passe Borg :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="53"/>
        <source>Overwrite existing profile</source>
        <translation>Écraser le profil existant</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="60"/>
        <source>Overwrite existing settings</source>
        <translation>Écraser les paramètres existant</translation>
    </message>
</context>
<context>
    <name>EditProfileWindow</name>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="68"/>
        <source>Rename Profile</source>
        <translation>Renommer le Profil</translation>
    </message>
</context>
<context>
    <name>ExistingRepoWindow</name>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="192"/>
        <source>Connect to existing Repository</source>
        <translation>Connexion à un dépôt existant</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="210"/>
        <source>Show my password</source>
        <translation>Afficher mon mot de passe</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="207"/>
        <source>Hide my password</source>
        <translation>Cacher mon mot de passe</translation>
    </message>
</context>
<context>
    <name>ExportWindow</name>
    <message>
        <location filename="../../views/export_window.py" line="29"/>
        <source>Export Profile</source>
        <translation>Exporter le Profil</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="38"/>
        <source>The current profile_export has no password</source>
        <translation>Le profil d&apos;export actuel n&apos;a pas de mot de passe.</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="43"/>
        <source>Save profile_export</source>
        <translation>Sauver l&apos;export de profil</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="55"/>
        <source>Error while exporting</source>
        <translation>Erreur de l&apos;export</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="71"/>
        <source>The file {} could not be created. Please choose another location.</source>
        <translation>Le fichier {} n&apos;a pu être créé. Veuillez choisir un autre emplacement.</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="78"/>
        <source>Profile export successful!</source>
        <translation>Profil exporté avec succès !</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="78"/>
        <source>Profile export written to {}.</source>
        <translation>Profil exporté vers {}.</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="14"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="44"/>
        <source>Archives</source>
        <translation>Archives</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="72"/>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="79"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="82"/>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="87"/>
        <source>Mount Point</source>
        <translation>Point de montage</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="92"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="125"/>
        <source>Check</source>
        <translation>Vérifier</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="145"/>
        <source>Prune</source>
        <translation>Élaguer</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="155"/>
        <source>Refresh</source>
        <translation>Rafraîchir</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="202"/>
        <source>Prune Options and Archive Naming</source>
        <translation>Configuration de l&apos;élagage et des noms d&apos;archives</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="229"/>
        <source>Keep</source>
        <translation>Conserver</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="253"/>
        <source>Use -1 for unlimited.</source>
        <translation>Utilisez « -1 » pour illimité.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="246"/>
        <source> hourly, </source>
        <translation>à l&apos;heure,</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="263"/>
        <source> daily, </source>
        <translation>au jour,</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="277"/>
        <source> weekly, </source>
        <translation>à la semaine,</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="291"/>
        <source> monthly and</source>
        <translation>au mois et</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="305"/>
        <source> annual archives</source>
        <translation>archives annuelles</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="332"/>
        <source>No matter what, keep all archives of the last:</source>
        <translation>Toujours conserver les archives des derniers/ières :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="342"/>
        <source>24H, 1d, 52w, 12m, 1y</source>
        <translation>24H, 1j, 52sem, 12m, 1a</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="382"/>
        <source>Archive Name:</source>
        <translation>Nom de l&apos;archive :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="425"/>
        <source>Available variables: hostname, profile_id, profile_slug, now, utc_now, user</source>
        <translation>Variables disponibles : hostname, profile_id, profile_slug, now, utc_now, user</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="392"/>
        <source>{hostname}-{profile_slug}-</source>
        <translation>{hostname}-{profile_slug}-</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="435"/>
        <source>Prune Prefix:</source>
        <translation>Préfixe d&apos;élagage :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="71"/>
        <source>0.0</source>
        <translation>0.0</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="55"/>
        <source>Repository:</source>
        <translation>Dépôt :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="128"/>
        <source>Select Backup Destination</source>
        <translation>Choisir la destination de la sauvegarde :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="136"/>
        <source>Unlink Repository (This doesn&apos;t delete any data. You can always add a repo again later.)</source>
        <translation>Dissocier un dépôt (Ceci ne supprime aucune donnée. Vous pouvez toujours ajouter un dépôt de nouveau ultérieurement.)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="164"/>
        <source>SSH Key:</source>
        <translation>Clé SSH :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="185"/>
        <source>Copy public SSH key to clipboard.</source>
        <translation>Copier la clé SSH vers le presse-papier.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="222"/>
        <source>To securely access remote repositories. Keep default to use all your existing keys. Or create new key.</source>
        <translation>Pour accéder à des dépôts distants de manière sécurisée. Utilisez la configuration par défaut pour utiliser toutes vos clés existantes. Créez une nouvelle clé sinon. </translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="246"/>
        <source>Compression:</source>
        <translation>Compression :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="347"/>
        <source>Encryption:</source>
        <translation>Chiffrement :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="387"/>
        <source>Original Size:</source>
        <translation>Taille d&apos;origine :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="401"/>
        <source>Deduplicated Size:</source>
        <translation>Taille dé-dupliquée :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="408"/>
        <source>Compressed Size:</source>
        <translation>Taille compressée :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="47"/>
        <source>Schedule</source>
        <translation>Planification</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="73"/>
        <source>Backup manually</source>
        <translation>Sauvegarder manuellement</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="90"/>
        <source>Backup every </source>
        <translation>Sauvegarder toutes les </translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="113"/>
        <source>hours at</source>
        <translation>heures à</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="136"/>
        <source>minutes past the hour</source>
        <translation>minutes passées l&apos;heure</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="160"/>
        <source>Backup daily at</source>
        <translation>Sauvegarder tous les jours, à</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="190"/>
        <source>Validate repository data every</source>
        <translation>Valider les données du dépôt toutes les </translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="216"/>
        <source>weeks</source>
        <translation>semaines</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="243"/>
        <source>Prune old Archives after each backup</source>
        <translation>Élaguer les anciennes archives après chaque sauvegarde</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="283"/>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="312"/>
        <source>Next Backup:</source>
        <translation>Prochaine sauvegarde :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="319"/>
        <source>Off</source>
        <translation>Éteint</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="363"/>
        <source>Networks</source>
        <translation>Réseaux</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="375"/>
        <source>Allowed Networks:</source>
        <translation>Réseaux autorisés :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="424"/>
        <source>Log</source>
        <translation>Historique</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="450"/>
        <source>Time</source>
        <translation>Temps</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="455"/>
        <source>Category</source>
        <translation>Catégorie</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="460"/>
        <source>Subcommand</source>
        <translation>Sous-commande</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="465"/>
        <source>Repository</source>
        <translation>Dépôt</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="470"/>
        <source>Returncode</source>
        <translation>Code de retour</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="487"/>
        <source>Shell Commands</source>
        <translation>Commandes de terminal</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="496"/>
        <source>Run custom shell commands before and after each backup. The actual backup and post-backup command will only run, if the pre-backup command exits without error (return code 0).</source>
        <translation>Exécuter une commande de terminal avant et après chaque sauvegarde. La commande de sauvegarde et post-sauvegarde seront exécutées uniquement si la commande pré-sauvegarde se termine sans erreur (code de retour 0)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="515"/>
        <source>Pre-backup command to run BEFORE backups</source>
        <translation>Commande pré-sauvegarde à exécuter AVANT les sauvegardes</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="525"/>
        <source>Post-backup command to run AFTER backups</source>
        <translation>Commande post-sauvegarde à exécuter APRÈS les sauvegardes</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="539"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Available env variables: &lt;span style=&quot; font-family:&apos;Courier&apos;;&quot;&gt;$repo_url, $profile_name, $profile_slug, $returncode&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Variables d&apos;environnement disponibles : &lt;span style=&quot; font-family:&apos;Courier&apos;;&quot;&gt;$repo_url, $profile_name, $profile_slug, $returncode&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="20"/>
        <source>Source Folders and Files to Back Up:</source>
        <translation>Dossiers sources et fichier à sauvegarder :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="94"/>
        <source>Add Folder</source>
        <translation>Ajouter un dossier</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="108"/>
        <source>Remove</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="164"/>
        <source>Exclude If Present (exclude folders with these files):</source>
        <translation>Exclure si présent (exclure les dossiers avec ces fichiers) :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="135"/>
        <source>Diff</source>
        <translation>Différence</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="183"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;To mount archives, first install &amp;quot;FUSE for macOS&amp;quot; from &lt;a href=&quot;https://osxfuse.github.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;here&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pour monter les archives, installez d&apos;abord &amp;quot;FUSE pour macOS&amp;quot; depuis&lt;a href=&quot;https://osxfuse.github.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;ici&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="208"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pruning removes older archives. You can choose the number of hourly, daily, etc. archives to preserve. Usually you will keep more newer and fewer old archives. Read &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/prune.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#FF4500;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;L&apos;élagage efface les archives les plus anciennes. Vous pouvez choisir le nombre d&apos;archives qui sont conservées par heure, jour, etc. En règle générale, on conserve plus d&apos;archives récentes et moins d&apos;anciennes. &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/prune.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#FF4500;&quot;&gt;En savoir plus&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="64"/>
        <source>Vorta Version:</source>
        <translation>Version de Vorta</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="81"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;| &lt;a href=&quot;https://github.com/borgbase/vorta/issues/new/choose&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Report&lt;/span&gt;&lt;/a&gt; a Bug |&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;| &lt;a href=&quot;https://github.com/borgbase/vorta/issues/new/choose&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Signaler un bug&lt;/span&gt;&lt;/a&gt; |</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="91"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;file:///&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Log&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;file:///&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Journal&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="127"/>
        <source>Borg Version:</source>
        <translation>Version de Borg:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="134"/>
        <source>1.1.8</source>
        <translation>1.1.8</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="141"/>
        <source>/usr/bin/borg</source>
        <translation>/usr/bin/borg</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="96"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Remote or local backup repository. For simple and secure backup hosting, try &lt;a href=&quot;https://www.borgbase.com/?utm_source=vorta&amp;amp;utm_medium=app&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;BorgBase&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Dépôt de sauvegarde local ou distant. Pour un hébergement de sauvegardes simple et sécurisé, essayez &lt;a href=&quot;https://www.borgbase.com/?utm_source=vorta&amp;amp;utm_medium=app&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;
BorgBase&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="288"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Compression used for new data. Can be changed and doesn&apos;t affect deduplication. Read &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-compression&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;La compression est utilisée pour les nouvelles données. Cela peut-être changé et n&apos;affecte pas la déduplication. En &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-compression&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;savoir plus&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="154"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Exclude Patterns (&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-patterns&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;):&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Exclure les motifs (&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-patterns&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;plus&lt;/span&gt;&lt;/a&gt;):&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="180"/>
        <source>E.g. **/.cache</source>
        <translation>Ex. **/.cache</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="193"/>
        <source>E.g. .nobackup</source>
        <translation>Ex. .nobackup</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="146"/>
        <source>Copy repo URL to clipboard</source>
        <translation>Copier l&apos;URL du dépôt dans le presse-papier</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="382"/>
        <source>Don&apos;t run backup over metered networks</source>
        <translation>Ne pas lancer de sauvegarde via une connexion limitée.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="101"/>
        <source>Add File(s)</source>
        <translation>Ajouter des fichiers</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="115"/>
        <source>One folder or file per line</source>
        <translation>Un dossier ou fichier par ligne</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="118"/>
        <source>Paste Folders/Files</source>
        <translation>Coller les Dossiers/Fichiers</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="428"/>
        <source>{hostname}-{profile_slug}-{now:%Y-%m-%d-%H%M%S}</source>
        <translation>{hostname}-{profile_slug}-{now:%Y-%m-%d-%H%M%S}</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="69"/>
        <source>Path</source>
        <translation>Chemin</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="74"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="84"/>
        <source>File Count</source>
        <translation>Nombre de fichiers</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="125"/>
        <source>Recalculate sizes</source>
        <translation>Recalculer les tailles</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="102"/>
        <source>Selected Archive</source>
        <translation>Archive sélectionnée</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="562"/>
        <source>Add these arguments when creating a backup. See &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/create.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;the documentation&lt;/span&gt;&lt;/a&gt; for more information.</source>
        <translation>Ajouter ces paramètres lors de la création d&apos;une sauvegarde. Voir &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/create.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;la documentation&lt;/span&gt;&lt;/a&gt; pour plus d&apos;informations.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="578"/>
        <source>Arguments to add. E.g. --dry-run</source>
        <translation>Arguments à ajouter. Ex: --dry-run</translation>
    </message>
</context>
<context>
    <name>ImportWindow</name>
    <message>
        <location filename="../../views/import_window.py" line="24"/>
        <source>Import Profile</source>
        <translation>Importer le Profil</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="32"/>
        <source>The passphrase has been loaded from the export file</source>
        <translation>Le mot de passe a été chargé depuis le fichier d&apos;export</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="39"/>
        <source>The passphrase has been loaded from your keyring</source>
        <translation>Le mot de passe a été chargé depuis votre trousseau de clés.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="49"/>
        <source>A profile with the name {} does not exist. Nothing to overwrite.</source>
        <translation>Il n&apos;y a pas de profil correspondant au nom {}. Rien à remplacer.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="60"/>
        <source>Error while importing</source>
        <translation>Erreur pendant l&apos;importation</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="76"/>
        <source>Schema upgrade failure, file a bug report with the link in the Misc tab with the following error: 
 {0} 
 {1}</source>
        <translation>Échec de la mise à niveau de la base de donnée, veuillez remplir un rapport de bug en utilisant le lien dans l&apos;onglet Divers avec l&apos;erreur suivante : 
{0} 
{1}</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="79"/>
        <source>Newer profile_export export files cannot be used on older versions.</source>
        <translation>Les nouveaux fichiers d&apos;export de profil ne peuvent être importés dans les anciennes versions.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="81"/>
        <source>Cannot read profile_export export file due to permission error.</source>
        <translation>Erreur de permission: impossible de lire le fichier d&apos;export de profil </translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="83"/>
        <source>Profile export file not found.</source>
        <translation>Fichier de profil exporté non trouvé.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../views/main_window.py" line="256"/>
        <source>Task cancelled</source>
        <translation>Tâche annulée</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="20"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="51"/>
        <source>Current Profile:</source>
        <translation>Profil actuel :</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="84"/>
        <source>Rename Profile</source>
        <translation>Renommer le profil</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="107"/>
        <source>Delete Profile</source>
        <translation>Supprimer le profil</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="148"/>
        <source>Repository</source>
        <translation>Dépôts</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="153"/>
        <source>Sources</source>
        <translation>Sources</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="158"/>
        <source>Schedule</source>
        <translation>Planification</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="163"/>
        <source>Archives</source>
        <translation>Archives</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="168"/>
        <source>Misc</source>
        <translation>Divers</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="190"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="36"/>
        <source>Start Backup</source>
        <translation>Commencer la sauvegarde</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="239"/>
        <source>Latest</source>
        <translation>Dernier</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="244"/>
        <source>Reset App</source>
        <translation>Réinitialiser l&apos;app</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="68"/>
        <source>Add Profile</source>
        <translation>Ajouter un profil</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="165"/>
        <source>Are you sure you want to delete profile &apos;{}&apos;?</source>
        <translation>Êtes vous sûr·e de vouloir supprimer le profil &apos;{}&apos;?</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="166"/>
        <source>Confirm deletion</source>
        <translation>Confirmer la suppression</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="273"/>
        <source>Should Vorta continue to run in the background?</source>
        <translation>Vorta doit-il continuer de tourner en arrière-plan ?</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="278"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="279"/>
        <source>Don&apos;t show this again</source>
        <translation>Ne plus afficher</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="84"/>
        <source>Import from file...</source>
        <translation>Importer d&apos;un fichier...</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="177"/>
        <source>Can&apos;t delete the last profile.</source>
        <translation>Impossible de supprimer le dernier profil.</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="205"/>
        <source>Profile import successful!</source>
        <translation>Profil importé avec succès !</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="205"/>
        <source>Profile {} imported.</source>
        <translation>Profil {} importé.</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="214"/>
        <source>Load profile</source>
        <translation>Charger le profil</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="214"/>
        <source>JSON (*.json);;All files (*)</source>
        <translation>JSON (*.json);;Tous les fichiers (*)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="97"/>
        <source>Export Profile</source>
        <translation>Exporter le Profil</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="223"/>
        <source>Failed to import profile</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoTab</name>
    <message>
        <location filename="../../views/repo_tab.py" line="26"/>
        <source>+ Initialize New Repository</source>
        <translation>+ Initialiser un nouveau dépôt</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="27"/>
        <source>+ Add Existing Repository</source>
        <translation>+ Ajouter un dépôt existant</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="48"/>
        <source>No Compression</source>
        <translation>Pas de compression</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="111"/>
        <source>Automatically choose SSH Key (default)</source>
        <translation>Choisir automatiquement une clef SSH (par défaut)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="112"/>
        <source>Create New Key</source>
        <translation>Créer une nouvelle clé</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="149"/>
        <source>Public Key Copied to Clipboard</source>
        <translation>Clé publique copiée dans le presse-papier</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="150"/>
        <source>The selected public SSH key was copied to the clipboard. Use it to set up remote repo permissions.</source>
        <translation>La clé SSH sélectionnée a été copiée dans le presse-papier. Utilisez la pour configurer les permissions du dépôt distant. </translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="155"/>
        <source>Couldn&apos;t find public key.</source>
        <translation>Clé publique introuvable.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="157"/>
        <source>Select a public key from the dropdown first.</source>
        <translation>Sélectionnez d&apos;abord une clé dans le menu déroulant. </translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="213"/>
        <source>Repository was Unlinked</source>
        <translation>Le dépôt est dissocié</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="214"/>
        <source>You can always connect it again later.</source>
        <translation>Vous pouvez toujours le reconnecter ultérieurement. </translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="38"/>
        <source>LZ4 (modern, default)</source>
        <translation>LZ4 (moderne, par défaut)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="39"/>
        <source>Zstandard Level 3 (modern)</source>
        <translation>Zstandard Niveau 3 (moderne)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="40"/>
        <source>Zstandard Level 8 (modern)</source>
        <translation>Zstandard Niveau 8 (moderne)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="46"/>
        <source>ZLIB Level 6 (auto, legacy)</source>
        <translation>ZLIB Niveau 6 (auto, ancien)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="47"/>
        <source>LZMA Level 6 (auto, legacy)</source>
        <translation>LZMA Niveau 6 (auto, ancien)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="228"/>
        <source>Select a repository from the dropdown first.</source>
        <translation>Sélectionnez d&apos;abord un dépôt dans le menu déroulant.</translation>
    </message>
</context>
<context>
    <name>SSHAddWindow</name>
    <message>
        <location filename="../../views/ssh_dialog.py" line="35"/>
        <source>ED25519 (Recommended)</source>
        <translation>ED25519 (Recommandé)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="36"/>
        <source>RSA (Legacy)</source>
        <translation>RSA (Classique)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="37"/>
        <source>ECDSA</source>
        <translation>ECDSA</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="46"/>
        <source>High (Recommended)</source>
        <translation>Haut (Recommandé)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="47"/>
        <source>Medium</source>
        <translation>Moyen</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="60"/>
        <source>Key file already exists. Not overwriting.</source>
        <translation>Le fichier clé existe déjà. Il ne sera pas écrasé. </translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="72"/>
        <source>New key was copied to clipboard and written to %s.</source>
        <translation>La nouvelle clé a été copiée dans le presse-papier et écrite sous %s.</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="74"/>
        <source>Error during key generation.</source>
        <translation>Erreur durant la génération de la clé.</translation>
    </message>
</context>
<context>
    <name>SourceTab</name>
    <message>
        <location filename="../../views/source_tab.py" line="171"/>
        <source>Choose directory to back up</source>
        <translation>Choisissez le répertoire à sauvegarder</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="171"/>
        <source>Choose file(s) to back up</source>
        <translation>Choisissez les fichier à sauvegarder</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="128"/>
        <source>Folder</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="132"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="102"/>
        <source>Calculating...</source>
        <translation>Calcul en cours…</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="162"/>
        <source>You don&apos;t have read access to {dir}.</source>
        <translation>Vous n&apos;avez pas d&apos;accès en lecture à {dir}.</translation>
    </message>
</context>
<context>
    <name>TrayMenu</name>
    <message>
        <location filename="../../tray_menu.py" line="43"/>
        <source>Vorta for Borg Backup</source>
        <translation>Vorta pour BorgBackup</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="52"/>
        <source>Backup in Progress</source>
        <translation>Sauvegarde en cours</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="53"/>
        <source>Cancel Backup</source>
        <translation>Annuler la sauvegarde</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="56"/>
        <source>Next Task: %s</source>
        <translation>Prochaine tâche : %s</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="65"/>
        <source>Backup Now</source>
        <translation>Sauvegarder maintenant</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="70"/>
        <source>Quit</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>VortaApp</name>
    <message>
        <location filename="../../application.py" line="129"/>
        <source>Vorta Backup</source>
        <translation>Sauvegarde Vorta</translation>
    </message>
    <message>
        <location filename="../../application.py" line="186"/>
        <source>No Borg Binary Found</source>
        <translation>Aucun binaire de Borg n&apos;a été trouvé</translation>
    </message>
    <message>
        <location filename="../../application.py" line="187"/>
        <source>Vorta was unable to locate a usable Borg Backup binary.</source>
        <translation>Vorta n&apos;a pas pu localiser un binaire de Borg Backup utilisable.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="224"/>
        <source>Repository In Use</source>
        <translation>Dépôt en cours d&apos;utilisation</translation>
    </message>
    <message>
        <location filename="../../application.py" line="226"/>
        <source>Abort</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../application.py" line="227"/>
        <source>Continue</source>
        <translation>Continuer</translation>
    </message>
    <message>
        <location filename="../../application.py" line="229"/>
        <source>The repository at {repo_url} might be in use elsewhere.</source>
        <translation>Le dépôt {repu_url} est susceptible d&apos;être utilisé autre part.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="230"/>
        <source>Only break the lock if you are certain no other Borg process on any machine is accessing the repository. Abort or break the lock?</source>
        <translation>Ne brisez le verrou que si vous êtes certain qu&apos;aucun autre processus Borg sur aucune machine n&apos;accède au dépôt. Abandonner ou casser le verrou ?</translation>
    </message>
    <message>
        <location filename="../../application.py" line="238"/>
        <source>You do not have permission to access the repository at {repo_url}. Gain access and try again.</source>
        <translation>Vous n&apos;avez pas la permission d&apos;accéder au dépôt {repo_url}. Récupérez le droit d&apos;accès et essayez à nouveau.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="241"/>
        <source>No Repository Permissions</source>
        <translation>Pas de permissions sur ce dépôt</translation>
    </message>
    <message>
        <location filename="../../application.py" line="205"/>
        <source>Vorta needs Full Disk Access for complete Backups</source>
        <translation>Vorta a besoin de l&apos;Accès complet au disque pour effectuer les sauvegardes</translation>
    </message>
    <message>
        <location filename="../../application.py" line="206"/>
        <source>Without this, some files won&apos;t be accessible and you may end up with an incomplete backup. Please set &lt;b&gt;Full Disk Access&lt;/b&gt; permission for Vorta in &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;System Preferences &gt; Security &amp; Privacy&lt;/a&gt;.</source>
        <translation>Sans cela, certains fichiers ne seront pas accessibles et vous risquez de vous retrouver avec une sauvegarde incomplète.  Veuillez activer la permission d&apos;&lt;b&gt;Accès complet au disque&lt;/b&gt; pour Vorta, dans les &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;Préférences Système &gt; Sécurité &amp; confidentialité&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="278"/>
        <source>Profile import successful!</source>
        <translation>Profil importé avec succès !</translation>
    </message>
    <message>
        <location filename="../../application.py" line="278"/>
        <source>Profile {} imported.</source>
        <translation>Profil {} importé</translation>
    </message>
    <message>
        <location filename="../../application.py" line="265"/>
        <source>Failed to import profile</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../application.py" line="265"/>
        <source>Failed to import a profile from {}:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../application.py" line="265"/>
        <source>Consider removing or repairing this file to get rid of this message.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VortaScheduler</name>
    <message>
        <location filename="../../scheduler_old.py" line="95"/>
        <source>None scheduled</source>
        <translation>Aucune planifiée</translation>
    </message>
    <message>
        <location filename="../../scheduler_old.py" line="126"/>
        <source>Vorta Backup</source>
        <translation>Vorta Backup</translation>
    </message>
    <message>
        <location filename="../../scheduler_old.py" line="104"/>
        <source>Starting background backup for %s.</source>
        <translation>Début de la sauvegarde en arrière-plan pour %s.</translation>
    </message>
    <message>
        <location filename="../../scheduler_old.py" line="115"/>
        <source>Backup successful for %s.</source>
        <translation>Sauvegarde réussie pour %s.</translation>
    </message>
    <message>
        <location filename="../../scheduler_old.py" line="121"/>
        <source>Error during backup creation.</source>
        <translation>Erreur durant la création de la sauvegarde. </translation>
    </message>
</context>
<context>
    <name>app</name>
    <message>
        <location filename="../../__main__.py" line="22"/>
        <source>Fatal Error</source>
        <translation>Erreur fatale</translation>
    </message>
    <message>
        <location filename="../../__main__.py" line="23"/>
        <source>Uncaught exception, please file a report with this text at
https://github.com/borgbase/vorta/issues/new
</source>
        <translation>Erreur non prise en charge, veuillez remplir un rapport de bug avec ce texte à l&apos;adresse suivante
https://github.com/borgbase/vorta/issues/new
</translation>
    </message>
</context>
<context>
    <name>messages</name>
    <message>
        <location filename="../../borg/borg_thread.py" line="117"/>
        <source>Backup is already in progress.</source>
        <translation>La sauvegarde est déjà en cours.</translation>
    </message>
    <message>
        <location filename="../../borg/version.py" line="20"/>
        <source>Borg binary was not found.</source>
        <translation>Le binaire Borg est introuvable.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_thread.py" line="125"/>
        <source>Add a backup repository first.</source>
        <translation>D&apos;abord, ajoutez un dépôt de sauvegarde.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="82"/>
        <source>Add some folders to back up first.</source>
        <translation>Ajouter des dossiers à sauvegarder d&apos;abord. </translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="98"/>
        <source>Current Wifi is not allowed.</source>
        <translation>Ce réseau WI-FI n&apos;est pas autorisé.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="115"/>
        <source>Repo folder not mounted or moved.</source>
        <translation>Le dossier des dépôts n&apos;est pas monté ou a été déplacé. </translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="111"/>
        <source>Pre-backup command returned non-zero exit code.</source>
        <translation>La commande pré-sauvegarde a retourné un code de retour non nul. </translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="165"/>
        <source>Starting backup...</source>
        <translation>Début de la sauvegarde...</translation>
    </message>
    <message>
        <location filename="../../borg/umount.py" line="27"/>
        <source>No active Borg mounts found.</source>
        <translation>Aucun point de montage Borg actif n&apos;a été trouvé. </translation>
    </message>
    <message>
        <location filename="../../borg/borg_thread.py" line="129"/>
        <source>Your Borg version is too old. &gt;=1.1.0 is required.</source>
        <translation>Votre version de Borg est trop ancienne. Une version &gt;=1.1.0 est requise.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="119"/>
        <source>Your current Borg version does not support ZStd compression.</source>
        <translation>La version actuelle de Borg ne supporte pas la compression ZStd.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="103"/>
        <source>Not running backup over metered connection.</source>
        <translation>Connexion limitée : la sauvegarde ne va pas être lancée.</translation>
    </message>
    <message>
        <location filename="../../borg/info_repo.py" line="42"/>
        <source>Please unlock your password manager.</source>
        <translation>Veuillez déverrouiller votre gestionnaire de mot de passe.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_thread.py" line="155"/>
        <source>Your repo passphrase was stored in a password manager which is no longer available.
Try unlinking and re-adding your repo.</source>
        <translation>Le mot de passe du dépôt a été enregistré dans un gestionnaire de mot de passe qui n&apos;est plus disponible.
Essayez de dissocier et d&apos;ajouter le dépôt à nouveau.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_thread.py" line="139"/>
        <source>Please unlock your system password manager or disable it under Misc</source>
        <translation>Veuillez déverrouiller votre gestionnaire de mot de passe système ou le désactiver dans l&apos;onglet Divers.</translation>
    </message>
</context>
<context>
    <name>settings</name>
    <message>
        <location filename="../../models.py" line="205"/>
        <source>Display notifications when background tasks fail</source>
        <translation>Afficher une notifications lorsqu&apos;une tâche en arrière-plan échoue.</translation>
    </message>
    <message>
        <location filename="../../models.py" line="210"/>
        <source>Also notify about successful background tasks</source>
        <translation>Informer également du succès de l&apos;exécution des tâches en arrière-plan</translation>
    </message>
    <message>
        <location filename="../../models.py" line="215"/>
        <source>Automatically start Vorta at login</source>
        <translation>Lancer automatiquement Vorta à l&apos;ouverture de session</translation>
    </message>
    <message>
        <location filename="../../models.py" line="255"/>
        <source>Check for updates on startup</source>
        <translation>Vérifier les mises à jour au démarrage</translation>
    </message>
    <message>
        <location filename="../../models.py" line="260"/>
        <source>Include pre-release versions when checking for updates</source>
        <translation>Rechercher également les versions bêta lors de la vérification des mises à jour</translation>
    </message>
    <message>
        <location filename="../../models.py" line="220"/>
        <source>Open main window on startup</source>
        <translation>Ouvrir la fenêtre principale au démarrage</translation>
    </message>
    <message>
        <location filename="../../models.py" line="225"/>
        <source>Get statistics of file/folder when added</source>
        <translation>Obtenir des statistiques sur les fichiers/dossiers lors de l&apos;ajout</translation>
    </message>
    <message>
        <location filename="../../models.py" line="268"/>
        <source>Display background exit dialog</source>
        <translation>Afficher le dialogue de tâche d&apos;arrière-plan à la sortie</translation>
    </message>
    <message>
        <location filename="../../models.py" line="235"/>
        <source>Try to replace existing permissions when mounting an archive.</source>
        <translation>Essayer de remplacer les permissions existantes lors du montage d&apos;une archive.</translation>
    </message>
    <message>
        <location filename="../../models.py" line="230"/>
        <source>Store repository passwords in system keychain, if available.</source>
        <translation>Stocker les mots de passe du dépôt dans le trousseau de clés du système, si disponible</translation>
    </message>
</context>
<context>
    <name>utils</name>
    <message>
        <location filename="../../utils.py" line="329"/>
        <source>Passwords must be identical and greater than 8 characters long.</source>
        <translation>Les mots de passe doivent être identiques et comporter plus de 8 caractères.</translation>
    </message>
    <message>
        <location filename="../../utils.py" line="331"/>
        <source>Passwords must be identical.</source>
        <translation>Les mots de passe doivent être identiques.</translation>
    </message>
    <message>
        <location filename="../../utils.py" line="333"/>
        <source>Passwords must be greater than 8 characters long.</source>
        <translation>Les mots de passe doivent faire plus de 8 caractères.</translation>
    </message>
</context>
</TS>